-- *************************************
-- Use Replace to change the following two items
-- (1) Replace <DB> with the name of the database to create
--	usually: change <DB> to Basketball   (remove the brackets)
-- (2) Replace <PATH> with the full path to this file
--	example: change <PATH> to C:\Temp\Basketball\
-- *************************************

IF NOT EXISTS (SELECT * FROM sys.databases
	WHERE name = N'<DB>')
	CREATE DATABASE <DB>
GO
USE <DB>
--
-- Create the path to the CSV files
--
DECLARE @data_path nvarchar(256);
SELECT @data_path = '<PATH>';
--

-- *************************************
-- Drop existing tables
-- *************************************

IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'PlayerGameStats')
   drop table PlayerGameStats;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'GameResults')
  drop table GameResults;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Players')
  drop table Players;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Games')
  drop table Games;
--
IF EXISTS (SELECT * FROM sys.tables
	WHERE name = N'Teams')
  drop table Teams;
--

-- *************************************
-- Create the tables
-- *************************************

CREATE TABLE Teams
(
   TeamID int NOT NULL,
   TeamName nvarchar(255) NULL,
   City nvarchar(255) NULL,
   Abbreviation nvarchar(255) NULL,
   Conference nvarchar(255) NULL,
   Division nvarchar(255) NULL,
   CONSTRAINT pk_Teams PRIMARY KEY (TeamID)
);

CREATE TABLE Games
(
   GameID int NOT NULL,
   GameNumber int NULL,
   GameDate datetime NULL,
   HomeTeam int NULL,
   Playoff bit NULL,
   BaseTeam int NULL,
   Comments nvarchar(255) NULL,
   CONSTRAINT pk_Games PRIMARY KEY (GameID)
);

CREATE TABLE Players
(
   PlayerID int NOT NULL,
   FirstName nvarchar(255) NULL,
   MiddleName nvarchar(255) NULL,
   LastName nvarchar(255) NULL,
   Suffix nvarchar(255) NULL,
   NickName nvarchar(255) NULL,
   DateOfBirth datetime NULL,
   BirthCity nvarchar(255) NULL,
   BirthState nvarchar(255) NULL,
   BirthCountry nvarchar(255) NULL,
   Height_Feet int NULL,
   Height_Inches int NULL,
   Weight int NULL,
   Position nvarchar(255) NULL,
   College nvarchar(255) NULL,
   CollegeState nvarchar(255) NULL,
   HighSchool nvarchar(255) NULL,
   HighSchoolCity nvarchar(255) NULL,
   HighSchoolState nvarchar(255) NULL,
   DraftYear int NULL,
   DraftPosition int NULL,
   DraftTeamCode nvarchar(100) NULL,
   CONSTRAINT pk_Players PRIMARY KEY (PlayerID)
);

CREATE TABLE GameResults
(  GameID int NOT NULL,
   TeamID int NOT NULL,
   Points int NULL,
   Won_Loss nvarchar(255) NULL,
   GameDate datetime NULL,
   OpponentID int NULL,
   OpponentPoints int NULL,
   IsHomeTeam bit NULL,
   IsPlayoff bit NULL,
   Comments nvarchar(512) NULL
   CONSTRAINT pk_GameResults PRIMARY KEY (GameID, TeamID),
   CONSTRAINT fk_GameResultsGame FOREIGN KEY (GameID)
     REFERENCES Games (GameID)
     ON DELETE CASCADE
)
;

CREATE TABLE PlayerGameStats
(
   GameID int NOT NULL,
   PlayerID int NOT NULL,
   TeamID int NOT NULL,
   MinutesPlayed float(53) NULL,
   FG int NULL,
   FGA int NULL,
   TP int NULL,
   TPA int NULL,
   FT int NULL,
   FTA int NULL,
   ORB int NULL,
   DRB int NULL,
   TRB int NULL,
   AST int NULL,
   STL int NULL,
   BLK int NULL,
   TOV int NULL,
   PF int NULL,
   PTS int NULL,
   CONSTRAINT pk_PlayerGameStats PRIMARY KEY (GameID, PlayerID),
   CONSTRAINT fk_PGS_Games FOREIGN KEY (GameID)
     REFERENCES Games (GameID)
     ON DELETE CASCADE,
   CONSTRAINT fk_PGS_Players FOREIGN KEY (PlayerID)
     REFERENCES Players (PlayerID)
     ON DELETE CASCADE,
   CONSTRAINT fk_PGS_Teams FOREIGN KEY (TeamID)
     REFERENCES Teams (TeamID)
     ON DELETE CASCADE
);
-- FG=field goals, FGA=field goals attempted
-- TP=three point shots, TPA=three pointers attempted
-- FT=free throws made, FTA=free throws attempted
-- ORB=offensive rebounds, DRB=defensive rebounds, TRB=total rebounds
-- AST=assists, STL=steals, BLK=blocks, TOV=turnovers
-- PF=personal fouls, PTS=points

--
-- *************************************
-- Load table data
-- *************************************
--
EXECUTE (N'BULK INSERT Teams FROM ''' + @data_path + N'Teams.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
EXECUTE (N'BULK INSERT Games FROM ''' + @data_path + N'Games.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
EXECUTE (N'BULK INSERT Players FROM ''' + @data_path + N'Players.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '';'',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
EXECUTE (N'BULK INSERT GameResults FROM ''' + @data_path + N'GameResults.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
EXECUTE (N'BULK INSERT PlayerGameStats FROM ''' + @data_path + N'PlayerGameStats.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- ********************
-- List table names and row counts
-- ********************
GO
SET NOCOUNT ON
SELECT 'Teams' "Table", Count(*) "Rows" FROM Teams          UNION
SELECT 'Players',              Count(*) FROM Players        UNION
SELECT 'Games',                Count(*) FROM Games          UNION
SELECT 'GameResults',          Count(*) FROM GameResults    UNION
SELECT 'PlayerGameStats',      Count(*) FROM PlayerGameStats 
ORDER BY 1;
SET NOCOUNT OFF
Go

